package com.zjrs.ggfw.rlzysc.bpo.schedule.execute;

import com.zjrs.ggfw.rlzysc.bpo.schedule.Task;
import com.zjrs.ggfw.sggfw.bpo.RlzyscSjsbBPO;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import jakarta.annotation.Resource;

@Service
public class ZjsjsbTask implements Task {//职介数据上报
    private static final Logger LOG = LoggerFactory.getLogger(ZjsjsbTask.class);

    @Resource
    private RlzyscSjsbBPO rlzyscSjsbBPO;

    @Override
    public void excute(String cronid) {
        LOG.info("职介上报定时器执行");
        rlzyscSjsbBPO.xyUpdateOrDelDwJbxx("INS");
       rlzyscSjsbBPO.grJlxxSb("INS");
        rlzyscSjsbBPO.grQzyxSb("INS");
        rlzyscSjsbBPO.grQzdjSb("INS");
        rlzyscSjsbBPO.dwZpxxSb("INS");
        rlzyscSjsbBPO.zphxxSb("INS");
        rlzyscSjsbBPO.xyUpdateOrDelGrJbxx("INS");
        rlzyscSjsbBPO.xyUpdateOrDelDwJbxx("UPD");
        rlzyscSjsbBPO.grJlxxSb("UPD");
        rlzyscSjsbBPO.grQzyxSb("UPD");
        rlzyscSjsbBPO.grQzdjSb("UPD");
        rlzyscSjsbBPO.dwZpxxSb("UPD");
        rlzyscSjsbBPO.zphxxSb("UPD");
        rlzyscSjsbBPO.xyUpdateOrDelGrJbxx("UPD");
        rlzyscSjsbBPO.grJlxxSb("DEL");
        rlzyscSjsbBPO.grQzyxSb("DEL");
        rlzyscSjsbBPO.grQzdjSb("DEL");
        rlzyscSjsbBPO.dwZpxxSb("DEL");
        rlzyscSjsbBPO.zphxxSb("DEL");
        LOG.info("职介上报定时器结束");
    }
}

